@@ -41,7 +41,6 @@ documented just below this comment.
 #ifndef RMT_INCLUDED_H
 #define RMT_INCLUDED_H
 
-
 //! @cond Doxygen_Suppress
 
 // Set to 0 to not include any bits of Remotery in your build
@@ -121,7 +120,7 @@ documented just below this comment.
 // Platform identification
 #if defined(_WINDOWS) || defined(_WIN32)
     #define RMT_PLATFORM_WINDOWS
-#elif defined(__linux__) || defined(__FreeBSD__)
+#elif defined(__linux__) || defined(__FreeBSD__) || defined(__OpenBSD__)
     #define RMT_PLATFORM_LINUX
     #define RMT_PLATFORM_POSIX
 #elif defined(__APPLE__)
@@ -332,6 +331,12 @@ typedef enum rmtSampleFlags
 #define rmt_LogText(text)                                                           \
     RMT_OPTIONAL(RMT_ENABLED, _rmt_LogText(text))
 
+#define rmt_EnableSampling(enable)                                                           \
+    RMT_OPTIONAL(RMT_ENABLED, _rmt_EnableSampling(enable))
+
+#define rmt_SamplingEnabled()                                                           \
+    RMT_OPTIONAL(RMT_ENABLED, _rmt_SamplingEnabled())
+
 #define rmt_BeginCPUSample(name, flags)                                             \
     RMT_OPTIONAL(RMT_ENABLED, {                                                     \
         static rmtU32 rmt_sample_hash_##name = 0;                                   \
@@ -357,7 +362,7 @@ typedef void (*rmtFreePtr)(void* mm_context, void* ptr);
 typedef void (*rmtInputHandlerPtr)(const char* text, void* context);
 
 
-/*! Struture to fill in to modify Remotery default settings*/
+// Struture to fill in to modify Remotery default settings
 typedef struct rmtSettings
 {
     // Which port to listen for incoming connections on
@@ -404,7 +409,7 @@ typedef struct rmtSettings
 } rmtSettings;
 
 
-/*! Structure to fill in when binding CUDA to Remotery*/
+// Structure to fill in when binding CUDA to Remotery
 typedef struct rmtCUDABind
 {
     // The main context that all driver functions apply before each call
@@ -627,6 +632,8 @@ RMT_API void _rmt_SetCurrentThreadName(rmtPStr thread_name);
 RMT_API void _rmt_LogText(rmtPStr text);
 RMT_API void _rmt_BeginCPUSample(rmtPStr name, rmtU32 flags, rmtU32* hash_cache);
 RMT_API void _rmt_EndCPUSample(void);
+RMT_API void _rmt_EnableSampling(rmtBool enable);
+RMT_API rmtBool _rmt_SamplingEnabled();
 
 #if RMT_USE_CUDA
 RMT_API void _rmt_BindCUDA(const rmtCUDABind* bind);
